@@ -36,13 +36,17 @@ rules <- function(values, labels = NULL, name = NULL, right = TRUE) {
     }
   }
 
-  # Sanity checks
+  # validation checks
   if (length(labels) < length(values)) {
     insight::format_error("There cannot be less labels than reference values!")
   } else if (length(labels) > length(values) + 1) {
     insight::format_error("Too many labels for the number of reference values!")
   }
 
+  if (!is.numeric(values)) {
+    insight::format_error("Reference values must be numeric.")
+  }
+
   if (length(values) == length(labels) - 1) {
     if (is.unsorted(values)) {
       insight::format_error("Reference values must be sorted.")
@@ -91,6 +95,8 @@ is.rules <- function(x) inherits(x, "rules")
 #'   frame of class `effectsize_table`.
 #' @param rules Set of [rules()]. When `x` is a data frame, can be a name of an
 #'   established set of rules.
+#' @param transform a function (or name of a function) to apply to `x` before
+#'   interpreting. See examples.
 #' @param ... Currently not used.
 #' @inheritParams rules
 #'
@@ -109,6 +115,10 @@ is.rules <- function(x) inherits(x, "rules")
 #' interpret(c(0.35, 0.15), c("small" = 0.2, "large" = 0.4), name = "Cohen's Rules")
 #' interpret(c(0.35, 0.15), rules(c(0.2, 0.4), c("small", "medium", "large")))
 #'
+#' bigness <- rules(c(1, 10), c("small", "medium", "big"))
+#' interpret(abs(-5), bigness)
+#' interpret(-5, bigness, transform = abs)
+#'
 #' # ----------
 #' d <- cohens_d(mpg ~ am, data = mtcars)
 #' interpret(d, rules = "cohen1988")
@@ -123,8 +133,8 @@ is.rules <- function(x) inherits(x, "rules")
 #' interpret(eta2, rules = "field2013")
 #'
 #' X <- chisq.test(mtcars$am, mtcars$cyl == 8)
-#' interpret(oddsratio(X), rules = "chen2010")
-#' interpret(cramers_v(X), "lovakov2021")
+#' interpret(oddsratio(X), rules = "cohen1988")
+#' interpret(cramers_v(X), rules = "lovakov2021")
 #' @export
 interpret <- function(x, ...) {
   UseMethod("interpret")
@@ -133,7 +143,17 @@ interpret <- function(x, ...) {
 
 #' @rdname interpret
 #' @export
-interpret.numeric <- function(x, rules, name = attr(rules, "rule_name"), ...) {
+interpret.numeric <- function(x, rules, name = attr(rules, "rule_name"),
+                              transform = NULL, ...) {
+  # This is meant to circumvent https://github.com/easystats/report/issues/442
+  if (is.character(transform)) {
+    transform <- match.fun(transform)
+  } else if (!is.function(transform)) {
+    transform <- identity
+  }
+
+  x_tran <- transform(x)
+
   if (!inherits(rules, "rules")) {
     rules <- rules(rules)
   }
@@ -141,13 +161,16 @@ interpret.numeric <- function(x, rules, name = attr(rules, "rule_name"), ...) {
   if (is.null(name)) name <- "Custom rules"
   attr(rules, "rule_name") <- name
 
-  if (length(x) > 1) {
-    out <- vapply(x, .interpret, rules = rules, FUN.VALUE = character(1L))
+  if (length(x_tran) > 1) {
+    out <- vapply(x_tran, .interpret, rules = rules, FUN.VALUE = character(1L))
+    if (is.matrix(x_tran) || is.array(x_tran)) {
+      out <- structure(out, dim = dim(x_tran), dimnames = dimnames(x_tran))
+    }
   } else {
-    out <- .interpret(x, rules = rules)
+    out <- .interpret(x_tran, rules = rules)
   }
 
-  names(out) <- names(x)
+  names(out) <- names(x_tran)
 
   class(out) <- c("effectsize_interpret", class(out))
   attr(out, "rules") <- rules
@@ -156,11 +179,18 @@ interpret.numeric <- function(x, rules, name = attr(rules, "rule_name"), ...) {
 
 #' @rdname interpret
 #' @export
-interpret.effectsize_table <- function(x, rules, ...) {
+interpret.effectsize_table <- function(x, rules, transform = NULL, ...) {
   if (missing(rules)) insight::format_error("You {.b must} specify the rules of interpretation!")
 
+  # This is meant to circumvent https://github.com/easystats/report/issues/442
+  if (is.character(transform)) {
+    transform <- match.fun(transform)
+  } else if (!is.function(transform)) {
+    transform <- identity
+  }
+
   es_name <- colnames(x)[is_effectsize_name(colnames(x))]
-  value <- x[[es_name]]
+  value <- transform(x[[es_name]])
 
   x$Interpretation <- switch(es_name,
     ## std diff
@@ -178,7 +208,7 @@ interpret.effectsize_table <- function(x, rules, ...) {
     Cohens_w = ,
     Tschuprows_t = ,
     Tschuprows_t_adjusted = ,
-    fei = interpret_cramers_v(value, rules = rules),
+    Fei = interpret_fei(value, rules = rules),
 
     ## xtab 2x2
     Cohens_h = interpret_cohens_d(value, rules = rules),
