@@ -21,13 +21,18 @@
 #' interpret_p(c(.5, .02, 0.001))
 #' interpret_p(c(.5, .02, 0.001), rules = "rss")
 #'
+#' stars <- rules(c(0.001, 0.01, 0.05, 0.1), c("***", "**", "*", "+", ""),
+#'   right = FALSE, name = "stars"
+#' )
+#' interpret_p(c(.5, .02, 0.001), rules = stars)
+#'
 #' @keywords interpreters
 #' @export
 interpret_p <- function(p, rules = "default") {
   rules <- .match.rules(
     rules,
     list(
-      default = rules(c(0.05), c("significant", "not significant"),
+      default = rules(0.05, c("significant", "not significant"),
         name = "default", right = FALSE
       ),
       rss = rules(c(0.005, 0.05), c("significant", "suggestive", "not significant"),
